==> linkv_rtc_im_mini-0.0.4.tar.gz: example/lib/message_readed_ack_with_stime_page.dart <==
import 'dart:io';

import 'package:common_utils/common_utils.dart';
import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:linkv_rtc_im_mini/bean/lv_im_msg.dart';
import 'package:linkv_rtc_im_mini/rtm_flutter_plugin.dart';

class MediaMsgModel {
  String title;
  int subType;// 0文本  1图片 2音频 3视频
  Map json;
  var msg;
  LVIMMsgState sendState;

  static MediaMsgModel init(title,subType, json,{var msg, LVIMMsgState sendState}) {
    MediaMsgModel model = MediaMsgModel();
    model.title = title;
    model.subType = subType;
    model.json = json;
    model.msg = msg;
    model.sendState = sendState;
    return model;
  }
}

class MessageReadedAckWithStimePage extends StatefulWidget {
  MessageReadedAckWithStimePage({Key key, @required this.userid})
      : super(key: key);
  final String userid;

  @override
  _MessageReadedAckWithStimePageState createState() => _MessageReadedAckWithStimePageState();
}

class _MessageReadedAckWithStimePageState extends State<MessageReadedAckWithStimePage> {

  static const String TAG = "_MessageReadedAckWithStimePageState";
  List<MediaMsgModel> _msgList = <MediaMsgModel>[];
  TextEditingController msgController = TextEditingController();
  FocusNode focusNode = FocusNode();

  @override
  void initState() {
    super.initState();
    RtmFlutterPlugin.queryLocalPrivateHistoryMessage(
        widget.userid, 0, 50)
        .then((listData) {
      if (!ObjectUtil.isEmptyList(listData) && listData.length > 0) {
        for (LVIMMsg lvImMsg in listData) {
          _msgList.add(MediaMsgModel.init(
              lvImMsg.dbid.toString(), lvImMsg.subType, lvImMsg.toMap(),
              msg: lvImMsg,
              sendState: lvImMsg.sendState));
        }
        setState(() {});

        LVIMMsg lvimMsg = listData[0];
        int sTime = lvimMsg.stime;
        RtmFlutterPlugin.sendPrivateReadedAckWithStime(sTime, widget.userid)
            .then((result) {
          Fluttertoast.showToast(
              msg: "sendPrivateReadedAckWithStime，eCode = ${result.eCode}，rcode = ${result.rcode}",
              toastLength: Toast.LENGTH_LONG,
              gravity: ToastGravity.CENTER);
        });
      }
    });

  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("测试媒体文件消息"),
      ),
      body: GestureDetector(
        onTap: () {
          FocusScope.of(context).requestFocus(FocusNode());
        },
        child: Column(
          children: [
            Expanded(
              child: ListView.builder(
                itemBuilder: (ctx, index) {
                  var msg = _msgList[index].msg;
                  Widget mediaWidget = Container();
                  if ((_msgList[index].subType == 1 ||
                      _msgList[index].subType == 3) && msg != null && msg.imageFile != null && !ObjectUtil.isEmptyString(msg?.imageFile["localPath"])) {
                    mediaWidget = Image.file(File(msg.imageFile["localPath"]));
                  }
                  String unReadMessge = "未读";
                  if(_msgList[index].sendState == LVIMMsgState.readed_ack){
                    unReadMessge = "已读";
                  }
                  return Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      InkWell(
                        onTap: () {
                          if (_msgList[index].subType == 1){//图片
                            downloadImage(_msgList[index].json,index);
                          } else if (_msgList[index].subType == 2) { //音频
                            downloadAudio(_msgList[index].json,index);
                          } else if (_msgList[index].subType == 3) { //视频
                            downloadVideoImage(_msgList[index].json,index);
                          }
                        },
                        child: Container(
                          padding: const EdgeInsets.only(left: 10, right: 10),
                          height: 50,
                          alignment: Alignment.centerLeft,
                          child: (_msgList[index].msg != null)
                              ? Row(
                            children: [
                              mediaWidget,
                              Text("${_msgList[index].title}  $unReadMessge")
                            ],
                          )
                              : Text("${_msgList[index].title}  $unReadMessge"),
                        ),
                      ),
                      Container(height: 1, color: Colors.grey),
                    ],
                  );
                },
                itemCount: _msgList.length,
              ),
            ),
          ],
        ),
      ),
    );
  }

  ///下载音频文件
  void downloadAudio(json, index) {
    if (ObjectUtil.isEmptyMap(json)) {
      return;
    }
    print(TAG + "下载音频文件");
    RtmFlutterPlugin.downloadAudio(json).then((result) {
      print(TAG + "downloadAudio" + " code = ${result.eCode}");
    });
  }

  ///下载图片缩略图
  void downloadThumbnailImage(json) {
    print(TAG + "下载图片缩略图");
    RtmFlutterPlugin.downloadThumbnailImage(json).then((result) {
      print(TAG + "downloadThumbnailImage" + " code = ${result.eCode}");
    });
  }

  ///下载图片文件
  void downloadImage(json,index) {
    if (ObjectUtil.isEmptyMap(json)) {
      return;
    }
    print(TAG + "下载图片文件");
    RtmFlutterPlugin.downloadImage(json).then((result) {
      print(TAG + "downloadImage" + " code = ${result.eCode}");
      if(result.eCode == 0){
        _msgList[index].msg = result.msg;
        setState(() { });
      }
    });
  }

  ///下载视频首帧
  void downloadVideoImage(json,index) {
    if (ObjectUtil.isEmptyMap(json)) {
      return;
    }
    print(TAG + "下载视频首帧");
    RtmFlutterPlugin.downloadVideoImage(json).then((result) {
      print(TAG + "downloadVideoImage" + " code = ${result.eCode}");
      _msgList[index].msg = result.msg;
      setState(() { });
    });
  }

}

==> linkv_rtc_im_mini-0.0.5.tar.gz: example/lib/message_readed_ack_with_stime_page.dart <==
import 'dart:io';

import 'package:common_utils/common_utils.dart';
import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:linkv_rtc_im_mini/bean/lv_im_msg.dart';
import 'package:linkv_rtc_im_mini/rtm_flutter_plugin.dart';

class MediaMsgModel {
  String title;
  int subType;// 0文本  1图片 2音频 3视频
  Map json;
  var msg;
  LVIMMsgState sendState;

  static MediaMsgModel init(title,subType, json,{var msg, LVIMMsgState sendState}) {
    MediaMsgModel model = MediaMsgModel();
    model.title = title;
    model.subType = subType;
    model.json = json;
    model.msg = msg;
    model.sendState = sendState;
    return model;
  }
}

class MessageReadedAckWithStimePage extends StatefulWidget {
  MessageReadedAckWithStimePage({Key key, @required this.userid})
      : super(key: key);
  final String userid;

  @override
  _MessageReadedAckWithStimePageState createState() => _MessageReadedAckWithStimePageState();
}

class _MessageReadedAckWithStimePageState extends State<MessageReadedAckWithStimePage> {

  static const String TAG = "_MessageReadedAckWithStimePageState";
  List<MediaMsgModel> _msgList = <MediaMsgModel>[];
  TextEditingController msgController = TextEditingController();
  FocusNode focusNode = FocusNode();

  @override
  void initState() {
    super.initState();
    RtmFlutterPlugin.queryLocalPrivateHistoryMessage(
        widget.userid, 0, 50)
        .then((listData) {
      if (!ObjectUtil.isEmptyList(listData) && listData.length > 0) {
        for (LVIMMsg lvImMsg in listData) {
          _msgList.add(MediaMsgModel.init(
              lvImMsg.dbid.toString(), lvImMsg.subType, lvImMsg.toMap(),
              msg: lvImMsg,
              sendState: lvImMsg.sendState));
        }
        setState(() {});

        LVIMMsg lvimMsg = listData[0];
        int sTime = lvimMsg.stime;
        RtmFlutterPlugin.sendPrivateReadedAckWithStime(sTime, widget.userid)
            .then((result) {
          Fluttertoast.showToast(
              msg: "sendPrivateReadedAckWithStime，eCode = ${result.eCode}，rCode = ${result.rCode}",
              toastLength: Toast.LENGTH_LONG,
              gravity: ToastGravity.CENTER);
        });
      }
    });

  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("测试媒体文件消息"),
      ),
      body: GestureDetector(
        onTap: () {
          FocusScope.of(context).requestFocus(FocusNode());
        },
        child: Column(
          children: [
            Expanded(
              child: ListView.builder(
                itemBuilder: (ctx, index) {
                  var msg = _msgList[index].msg;
                  Widget mediaWidget = Container();
                  if ((_msgList[index].subType == 1 ||
                      _msgList[index].subType == 3) && msg != null && msg.imageFile != null && !ObjectUtil.isEmptyString(msg?.imageFile["localPath"])) {
                    mediaWidget = Image.file(File(msg.imageFile["localPath"]));
                  }
                  String unReadMessge = "未读";
                  if(_msgList[index].sendState == LVIMMsgState.readed_ack){
                    unReadMessge = "已读";
                  }
                  return Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      InkWell(
                        onTap: () {
                          if (_msgList[index].subType == 1){//图片
                            downloadImage(_msgList[index].json,index);
                          } else if (_msgList[index].subType == 2) { //音频
                            downloadAudio(_msgList[index].json,index);
                          } else if (_msgList[index].subType == 3) { //视频
                            downloadVideoImage(_msgList[index].json,index);
                          }
                        },
                        child: Container(
                          padding: const EdgeInsets.only(left: 10, right: 10),
                          height: 50,
                          alignment: Alignment.centerLeft,
                          child: (_msgList[index].msg != null)
                              ? Row(
                            children: [
                              mediaWidget,
                              Text("${_msgList[index].title}  $unReadMessge")
                            ],
                          )
                              : Text("${_msgList[index].title}  $unReadMessge"),
                        ),
                      ),
                      Container(height: 1, color: Colors.grey),
                    ],
                  );
                },
                itemCount: _msgList.length,
              ),
            ),
          ],
        ),
      ),
    );
  }

  ///下载音频文件
  void downloadAudio(json, index) {
    if (ObjectUtil.isEmptyMap(json)) {
      return;
    }
    print(TAG + "下载音频文件");
    RtmFlutterPlugin.downloadAudio(json).then((result) {
      print(TAG + "downloadAudio" + " code = ${result.eCode}");
    });
  }

  ///下载图片缩略图
  void downloadThumbnailImage(json) {
    print(TAG + "下载图片缩略图");
    RtmFlutterPlugin.downloadThumbnailImage(json).then((result) {
      print(TAG + "downloadThumbnailImage" + " code = ${result.eCode}");
    });
  }

  ///下载图片文件
  void downloadImage(json,index) {
    if (ObjectUtil.isEmptyMap(json)) {
      return;
    }
    print(TAG + "下载图片文件");
    RtmFlutterPlugin.downloadImage(json).then((result) {
      print(TAG + "downloadImage" + " code = ${result.eCode}");
      if(result.eCode == 0){
        _msgList[index].msg = result.msg;
        setState(() { });
      }
    });
  }

  ///下载视频首帧
  void downloadVideoImage(json,index) {
    if (ObjectUtil.isEmptyMap(json)) {
      return;
    }
    print(TAG + "下载视频首帧");
    RtmFlutterPlugin.downloadVideoImage(json).then((result) {
      print(TAG + "downloadVideoImage" + " code = ${result.eCode}");
      _msgList[index].msg = result.msg;
      setState(() { });
    });
  }

}
